#!/bin/bash

#Installation script for Nautilus Terminal

_install() {
	#Install Nautilus Terminal
	#$1 : the output path, if different of /
	#Share
	mkdir -pv "$1"/usr/share/nautilus-terminal/
	cp -v ./pixmaps/* "$1"/usr/share/nautilus-terminal/
	cp -v ./code/*.glade "$1"/usr/share/nautilus-terminal/
	#Nautilus Python
	mkdir -pv "$1"/usr/lib/nautilus/extensions-2.0/python/
	cp -pv ./code/nautilus-terminal.py "$1"/usr/lib/nautilus/extensions-2.0/python/
	chmod -v 755 "$1"/usr/lib/nautilus/extensions-2.0/python/nautilus-terminal.py
	#Doc
	mkdir -pv "$1"/usr/share/doc/nautilus-terminal/
	cp -v README "$1"/usr/share/doc/nautilus-terminal/
	cp -v AUTHORS "$1"/usr/share/doc/nautilus-terminal/
	#locales
	for file in `find ./locales -name "*.po"` ; do {
		l10elang=`echo $file | sed -r 's#./locales/(.*).po#\1#g'`
		mkdir -pv "$1"/usr/share/locale/$l10elang/LC_MESSAGES/
		msgfmt "$file" -o "$1"/usr/share/locale/$l10elang/LC_MESSAGES/nautilus-terminal.mo
	} done
	#Copy this script for uninstalling, (not for --package)
	if [ "$1" == "" ] ; then {
		cp -v ./install.sh /usr/share/nautilus-terminal/
	} fi
}


_remove() {
	#Remove Nautilus Terminal
	rm -rv /usr/share/nautilus-terminal
	rm -v /usr/lib/nautilus/extensions-2.0/python/nautilus-terminal.py
	rm -rv /usr/share/doc/nautilus-terminal
	find /usr/share/locale/ -name nautilus-terminal.mo \
		-exec rm -v '{}' ';'
}


_locale() {
	#Make the transtation template
	mkdir -pv ./locales/
	xgettext -k_ -kN_ -o ./locales/nautilus-terminal.pot ./code/*.py ./code/*.glade
	for lcfile in $(find ./locales/ -name "*.po") ; do {
		echo -n "   * $lcfile"
		msgmerge --update $lcfile ./locales/nautilus-terminal.pot
	} done
}

#Force english
export LANG=c
#Go to the scrip directory
cd "${0%/*}" 1> /dev/null 2> /dev/null

#Head text
echo "Nautilus Terminal - An integrated terminal for the Nautilus file browser."
echo

#Action do to
if [ "$1" == "--install" ] || [ "$1" == "-i" ] ; then {
	echo "Installing Nautilus Terminal..."
	if [ "$(whoami)" == "root" ] ; then {
		_install
	} else {
		echo "E: Need to be root"
		exit 1
	} fi
} elif [ "$1" == "--package" ] || [ "$1" == "-p" ] ; then {
	echo "Packaging Nautilus Terminal..."
	if [ -d "$2" ] ; then {
		_install "$2"
	} else {
		echo "E: '$2' is not a directory"
		exit 2
	} fi
} elif [ "$1" == "--remove" ] || [ "$1" == "-r" ] ; then {
	echo "Removing Nautilus Terminal..."
	if [ "$(whoami)" == "root" ] ; then {
		_remove
	} else {
		echo "E: Need to be root"
		exit 1
	} fi
} elif [ "$1" == "--locale" ] || [ "$1" == "-l" ] ; then {
	echo "Extracting strings for the translation template..."
	if [ -x /usr/bin/xgettext ] ; then {
		_locale
	} else {
		echo "E: Can't find xgettext... gettex is installed ?"
		exit 3
	} fi
} else {
	echo "Arguments :"
	echo "  --install : install Nautilus Terminal on your computer."
	echo "  --package <path> : install Nautilus Terminal in <path> (Useful for packaging)."
	echo "  --remove : remove Nautilus Terminal from your computer."
	echo "  --locale : extract strings to for the translation template."
} fi

exit 0


